.. twittercollect documentation master file, created by
   sphinx-quickstart on Wed Jun 16 12:35:13 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to twittercollect's documentation!
==========================================

.. include:: README.rst

.. autofunction:: twittercollect.collect
.. autofunction:: twittercollect.parse

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
